@@ -12,13 +12,13 @@ class IsosurfaceCollection(FDSDataCollection):
     def __init__(self, *isosurfaces: Iterable[Isosurface]):
         super().__init__(*isosurfaces)
 
-    def filter_by_quantity(self, quantity: Union[str, Quantity]) -> List[Isosurface]:
+    def filter_by_quantity(self, quantity: Union[str, Quantity]):
         """Filters all isosurfaces by a specific quantity.
         """
         if type(quantity) != str:
             quantity = quantity.quantity
-        return [x for x in self if x.quantity.quantity.lower() == quantity.lower() or
-                x.quantity.label.lower() == quantity.lower()]
+        return IsosurfaceCollection(x for x in self if
+                                    x.quantity.quantity.lower() == quantity.lower() or x.quantity.label.lower() == quantity.lower())
 
     def __repr__(self):
         return "IsosurfaceCollection(" + super(IsosurfaceCollection, self).__repr__() + ")"
